@@ -6,6 +6,7 @@ from classytags.core import Options
 from classytags.arguments import Argument
 
 from shop.util.cart import get_or_create_cart
+from shop.models.productmodel import Product
 
 
 register = template.Library()
@@ -16,18 +17,18 @@ class Cart(InclusionTag):
     Inclusion tag for displaying cart summary.
     """
     template = 'shop/templatetags/_cart.html'
-    
+
     def get_context(self, context):
         cart = get_or_create_cart(context['request'])
         return {
             'cart': cart
-        } 
+        }
 register.tag(Cart)
 
 
 class Order(InclusionTag):
     """
-    Inclusio tag for displaying order.
+    Inclusion tag for displaying order.
     """
     template = 'shop/templatetags/_order.html'
     options = Options(
@@ -37,5 +38,22 @@ class Order(InclusionTag):
     def get_context(self, context, order):
         return {
             'order': order
-        } 
+        }
 register.tag(Order)
+
+
+class Products(InclusionTag):
+    """
+    Inclusion tag for displaying all products.
+    """
+    template = 'shop/templatetags/_products.html'
+    options = Options(
+        Argument('objects', resolve=True, required=False),
+    )
+
+    def get_context(self, context, objects):
+        if not objects:
+            objects = Product.objects.filter(active=True)
+        context.update({'products': objects, })
+        return context
+register.tag(Products)
